0.6.1
=====

2015-10-24

* fixed drawing area being one column smaller than it could be


0.6.0
=====

2015-08-09

* added ``--tle``
* added AOS/LOS info
* fixed observer azimuth and altitude not updating during timetravel


0.5.1
=====

2015-03-14

* fixed python-tag on wheel package


0.5.0
=====

2015-03-14

* now starts with no drawing options enabled by default
* added ``--night``
* added ``--paused``
* added ``--topo``
* orbit interpolation now starts at satellite position
* further improvements to performance and responsiveness
* fixed terminator not updating during timetravel


0.4.0
=====

2015-02-22

* added ``--aliases``
* added ``--coverage``
* added ``--footprint``
* added ``--grid``
* added ``--info``
* added ``--orbit-ascdesc``
* added hotkeys for most drawing options
* added hotkeys for timetravel
* added orbit marker interpolation
* improved overall performance
* removed map cropping near poles


0.3.1
=====

2015-02-08

* added missing data files to distribution


0.3.0
=====

2015-02-05

* added ``--body`` to draw the Moon or Mars
* added ``--no-night``
* added ``--orbit-res``
* added topographic features
* improved twilight shading
* various minor cosmetics


0.2.0
=====

2015-01-30

* added info panels
* added ``--apsides``
* added ``--crosshair``
* fixed excessive use of geolocation API
* fixed various overflow errors


0.1.0
=====

2015-01-26

* initial release
